@@ -1,7 +1,7 @@
 /*
  * midiinterface.cpp
  *
- * Copyright 2002-2016 Vesa Halttunen
+ * Copyright 2002-2019 Vesa Halttunen
  *
  * This file is part of Tutka.
  *
@@ -25,7 +25,7 @@
 
 MIDIInterface::MIDIInterface(DirectionFlags flags, QObject *parent) :
     QObject(parent),
-    name_("No output"),
+    name_(tr("No output")),
     flags_(flags),
     enabled(false),
     tick(0)
